"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NotificationApiEvent = exports.NotificationApi = void 0;
const AppNotification_1 = require("../model/AppNotification");
const Channel_1 = require("./Channel");
const BaseApi_1 = require("./BaseApi");
var NotificationApiEvent;
(function (NotificationApiEvent) {
    NotificationApiEvent["CONFIRM"] = "event::cn.widgetjs.core.notification.confirm";
    NotificationApiEvent["CANCEL"] = "event::cn.widgetjs.core.notification.cancel";
    NotificationApiEvent["HIDE"] = "event::cn.widgetjs.core.notification.hide";
})(NotificationApiEvent || (NotificationApiEvent = {}));
exports.NotificationApiEvent = NotificationApiEvent;
class NotificationApiImpl extends BaseApi_1.BaseApi {
    // static async url(url: string, duration: number = -1) {
    //     this.invoke(Channel.NOTIFICATION, new AppNotification({
    //         url, message: "",
    //         duration,
    //         type: "url",
    //     }));
    // }
    /**
     * 来电
     * @param avatar    头像地址
     * @param audio     音频地址
     * @param title     标题文件
     * @param message   初始消息
     * @param lyric     歌词字符串
     */
    async call(avatar, audio, title, message, lyric) {
        await this.invoke(new AppNotification_1.AppNotification({
            avatar,
            audio,
            message,
            title,
            duration: -1,
            lyric,
            type: "call",
        }));
    }
    async send(notification) {
        return this.invokeMethod('send', notification);
    }
    async reminder(title, message, icon, cancelButtonText, confirmButtonText, cancelBroadcast, confirmBroadcast, duration = 5000) {
        return await this.send(new AppNotification_1.AppNotification({
            icon,
            message,
            title,
            duration,
            cancelButtonText,
            confirmButtonText,
            cancelBroadcast,
            confirmBroadcast,
            type: "reminder",
        }));
    }
    async advanceCountdown(message, targetTime, title) {
        return await this.send(new AppNotification_1.AppNotification({
            title,
            message,
            targetTime,
            type: "advance-countdown"
        }));
    }
    async countdown(message, targetTime) {
        await this.send(new AppNotification_1.AppNotification({
            message,
            targetTime,
            backgroundColor: 'rgba(0,0,0,0.5)',
            duration: -1,
            type: "countdown"
        }));
    }
    async success(message, duration = 5000) {
        await this.send(new AppNotification_1.AppNotification({
            message,
            type: "success",
            icon: "check_circle_line",
            duration
        }));
    }
    async error(message, duration = 5000) {
        await this.send(new AppNotification_1.AppNotification({
            message,
            type: "error",
            icon: "close_circle_line",
            duration
        }));
    }
    async warning(message, duration = 5000) {
        await this.send(new AppNotification_1.AppNotification({
            message,
            type: "warning",
            icon: "warning_line",
            duration
        }));
    }
    async info(message, duration = 5000) {
        await this.send(new AppNotification_1.AppNotification({
            message,
            type: "info",
            icon: "information_line",
            duration
        }));
    }
    /**
     * 隐藏通知
     */
    async hide() {
        await this.invokeMethod('hide');
    }
    getChannel() {
        return Channel_1.Channel.NOTIFICATION;
    }
}
const NotificationApi = new NotificationApiImpl();
exports.NotificationApi = NotificationApi;
