import { Widget } from "../model/Widget";
import { WidgetPackage } from "../model/WidgetPackage";
import { Channel } from "./Channel";
import { UrlUtils } from "../utils/UrlUtils";
import { BaseApi } from "./BaseApi";
var WidgetApiEvent;
(function (WidgetApiEvent) {
    WidgetApiEvent["DATA_CHANGED"] = "event::cn.widgetjs.core.widget.data-changed";
    WidgetApiEvent["EDIT_DESKTOP_WIDGETS"] = "event::cn.widgetjs.core.widget.desktop.edit";
})(WidgetApiEvent || (WidgetApiEvent = {}));
class WidgetApiImpl extends BaseApi {
    getChannel() {
        return Channel.WIDGET;
    }
    async registerWidgets(widgets) {
        return this.invokeMethod("registerWidgets", JSON.stringify(widgets));
    }
    async registerWidgetPackage(widgetPackage) {
        return this.invokeMethod("registerWidgetPackage", JSON.stringify(widgetPackage));
    }
    async getWidgets() {
        const data = await this.invokeMethod('getWidgets');
        const widgets = [];
        if (data) {
            for (const item of data) {
                widgets.push(Widget.parseObject(item));
            }
        }
        return widgets;
    }
    async getWidgetPackages() {
        return await this.invokeMethod('getWidgetPackages');
    }
    /**
     *
     * @param name package name
     */
    async getWidget(name) {
        return Widget.parseObject(await this.invokeMethod('getWidget', name));
    }
    /**
     *
     * @param name package name
     */
    async getWidgetPackage(name) {
        return WidgetPackage.parseObject(await this.invokeMethod('getWidgetPackage', name));
    }
    /**
     * 获取组件配置地址
     * @param widgetName
     */
    async getWidgetConfigUrl(widgetName, widgetParams) {
        const widget = await this.getWidget(widgetName);
        if (!widget)
            return null;
        const configRoute = widget.getConfigRoute();
        if (!configRoute)
            return null;
        const widgetPackage = await this.getWidgetPackage(widget.packageName);
        if (!widgetPackage)
            return null;
        return UrlUtils.getWidgetUrl(configRoute.url, widgetPackage, widgetParams);
    }
    async getWidgetUrl(widgetName, widgetParams) {
        const widget = await this.getWidget(widgetName);
        if (!widget)
            return null;
        const indexRoute = widget.getIndexRoute();
        const widgetPackage = await this.getWidgetPackage(widget.packageName);
        if (!widgetPackage)
            return null;
        return UrlUtils.getWidgetUrl(indexRoute.url, widgetPackage, widgetParams);
    }
    async getWidgetPackageIndexUrl(packageName, hash) {
        const widgetPackage = await this.getWidgetPackage(packageName);
        if (!widgetPackage)
            return null;
        return widgetPackage.getIndexUrl(hash);
    }
    async getWidgetPackageUrl(packageName) {
        const widgetPackage = await this.getWidgetPackage(packageName);
        if (!widgetPackage)
            return null;
        return widgetPackage.url;
    }
}
const WidgetApi = new WidgetApiImpl();
export { WidgetApi, WidgetApiEvent };
