import localforage from "localforage";
import { BroadcastEvent } from "../model/event/BroadcastEvent";
import { BroadcastApi } from "./BroadcastApi";
import { WidgetApiEvent } from "./WidgetApi";
export class WidgetDataApiImpl {
    constructor() {
        this.stores = new Map();
    }
    /**
     * 保存组件数据
     * @param data
     */
    async save(data) {
        let store = this.getStore(data.name);
        let json = JSON.stringify(data);
        const result = await store.setItem(this.getKey(data.name, data.id), json);
        const broadcastEvent = new BroadcastEvent({
            event: WidgetApiEvent.DATA_CHANGED, payload: { name: data.name, json }
        });
        await BroadcastApi.send(broadcastEvent);
        return result;
    }
    /**
     * 获取组件 LocalForage 存储实例
     * @param name
     */
    getStore(name) {
        if (this.stores.has(name)) {
            return this.stores.get(name);
        }
        const store = localforage.createInstance({ name: name });
        this.stores.set(name, store);
        return store;
    }
    /**
     * 通过组件名保存组件信息，通常用于存储可以在同类组件中共用的数据
     * @param data
     * @param options
     */
    async saveByName(data, options = { sendBroadcast: true }) {
        const store = this.getStore(data.name);
        const json = JSON.stringify(data);
        const result = await store.setItem(data.name, json);
        if (options === null || options === void 0 ? void 0 : options.sendBroadcast) {
            const broadcastEvent = new BroadcastEvent({
                event: WidgetApiEvent.DATA_CHANGED, payload: { name: data.name, json }
            });
            await BroadcastApi.send(broadcastEvent);
        }
        return result;
    }
    async findByName(...args) {
        let name = '';
        let dbStr = '';
        let data;
        if (args.length === 2) {
            name = args[0];
            const type = args[1];
            data = new type(name);
        }
        else {
            data = args[0];
            name = data.name;
        }
        let store = this.getStore(name);
        dbStr = await store.getItem(name);
        if (dbStr) {
            data.parseJSON(JSON.parse(dbStr));
            return data;
        }
        return undefined;
    }
    async find(name, id, type) {
        let store = this.getStore(name);
        let result = await store.getItem(this.getKey(name, id));
        if (result) {
            const widgetData = new type(name, id);
            widgetData.parseJSON(JSON.parse(result));
            return widgetData;
        }
        return undefined;
    }
    getKey(name, id) {
        return `${name}@${id}`;
    }
}
const WidgetDataApi = new WidgetDataApiImpl();
export { WidgetDataApi };
