import { HostedMode } from "./HostedMode";
import { getTextByLanguageCode } from "../utils/LanguageUtils";
export class Widget {
    constructor(options) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        /**
         * 组件默认语言
         */
        this.lang = "zh";
        this.name = options.name;
        this.title = options.title;
        this.description = options.description;
        this.keywords = options.keywords;
        this.lang = options.lang;
        this.width = options.width;
        this.height = options.height;
        this.movable = (_a = options.movable) !== null && _a !== void 0 ? _a : true;
        this.permissions = (_b = options.permissions) !== null && _b !== void 0 ? _b : [];
        this.maxWidth = (_c = options.maxWidth) !== null && _c !== void 0 ? _c : options.width;
        this.maxHeight = (_d = options.maxHeight) !== null && _d !== void 0 ? _d : options.height;
        this.minWidth = (_e = options.minWidth) !== null && _e !== void 0 ? _e : options.width;
        this.minHeight = (_f = options.minHeight) !== null && _f !== void 0 ? _f : options.height;
        this.backgroundThrottling = (_g = options.backgroundThrottling) !== null && _g !== void 0 ? _g : true;
        this.packageName = options.packageName;
        this.previewImage = options.previewImage;
        this.shortcut = options.shortcut;
        this.refreshWhenResided = (_h = options.refreshWhenResided) !== null && _h !== void 0 ? _h : false;
        this.hideWhenBlur = options.hideWhenBlur == null ? false : options.hideWhenBlur;
        this.supportHostedMode = (_j = options.supportHostedMode) !== null && _j !== void 0 ? _j : HostedMode.NORMAL | HostedMode.OVERLAP;
        this.routes = options.routes;
    }
    getIndexRoute() {
        const result = this.routes.find((it) => it.name.toLowerCase() == 'index');
        return result;
    }
    getConfigRoute() {
        return this.routes.find((it) => it.name.toLowerCase() == 'config');
    }
    isConfigurable() {
        return this.getConfigRoute() != null;
    }
    /**
     * 获取组件标题
     * @param lang 语言环境，不传则获取默认语言
     */
    getTitle(lang) {
        return getTextByLanguageCode(this.title, lang);
    }
    /**
     * 获取组件描述
     * @param lang 语言环境，不传则获取默认标题
     */
    getDescription(lang) {
        return getTextByLanguageCode(this.description, lang);
    }
    static parseJSON(json) {
        const object = JSON.parse(json);
        return this.parseObject(object);
    }
    static parseObject(obj) {
        let widget = new Widget({
            description: {},
            height: 0,
            keywords: [],
            lang: "",
            name: "",
            routes: [],
            title: {},
            width: 0
        });
        Object.assign(widget, obj);
        return widget;
    }
    /**
     * 是否支持悬浮窗
     */
    isSupportOverlap() {
        return (this.supportHostedMode & HostedMode.OVERLAP) > 0;
    }
    isResizable() {
        return !(this.minWidth == this.width &&
            this.maxWidth == this.width &&
            this.minHeight == this.height &&
            this.maxHeight == this.height);
    }
    isSupportBackground() {
        return (this.supportHostedMode & HostedMode.BACKGROUND) > 0;
    }
    /**
     * 是否支持普通模式
     */
    isSupportNormal() {
        return (this.supportHostedMode & HostedMode.NORMAL) > 0;
    }
    isSupportWallpaper() {
        return (this.supportHostedMode & HostedMode.WALLPAPER) > 0;
    }
    isSupportScreen() {
        return (this.supportHostedMode & HostedMode.SCREEN) > 0;
    }
}
export var WidgetKeyword;
(function (WidgetKeyword) {
    WidgetKeyword["RECOMMEND"] = "recommend";
    WidgetKeyword["TOOLS"] = "tools";
    WidgetKeyword["EFFICIENCY"] = "efficiency";
    WidgetKeyword["PICTURE"] = "picture";
    WidgetKeyword["LIFE"] = "life";
    WidgetKeyword["SHORTCUT"] = "shortcut";
    WidgetKeyword["COUNTDOWN"] = "countdown";
    WidgetKeyword["TIMER"] = "timer";
    WidgetKeyword["INFO"] = "info";
    WidgetKeyword["DASHBOARD"] = "dashboard";
})(WidgetKeyword || (WidgetKeyword = {}));
