import { UrlUtils } from "../utils/UrlUtils";
import { getTextByLanguageCode } from "../utils/LanguageUtils";
export class WidgetPackage {
    constructor(options) {
        /**
         * Hash路由模式，默认为true
         */
        this.hash = true;
        this.widgets = [];
        this.name = options.name;
        this.version = options.version;
        this.author = options.author;
        this.homepage = options.homepage;
        this.title = options.title;
        this.description = options.description;
        this.entry = options.entry;
        this.remoteEntry = options.remoteEntry;
        this.remotePackage = options.remotePackage;
        this.hash = options.hash;
        this.url = options.url;
        this.devOptions = options.devOptions;
        if (options.widgets) {
            for (let widget of options.widgets) {
                this.widgets.push(widget);
            }
        }
    }
    static parseJSON(json) {
        const object = JSON.parse(json);
        return this.parseObject(object);
    }
    static parseObject(obj) {
        let widgetPackage = new WidgetPackage({
            author: "",
            description: {
                "zh-CN": "",
            },
            entry: "",
            hash: false,
            homepage: "",
            name: "",
            title: {
                "zh-CN": "",
            },
            url: "",
            version: ""
        });
        Object.assign(widgetPackage, obj);
        return widgetPackage;
    }
    /**
     * 获取组件包标题
     * @param lang 语言环境，不传则获取默认语言
     */
    getTitle(lang) {
        return getTextByLanguageCode(this.title, lang);
    }
    /**
     * 获取组件包描述
     * @param lang 语言环境，不传则获取默认标题
     */
    getDescription(lang) {
        return getTextByLanguageCode(this.description, lang);
    }
    /**
     * 获取组件完整路径
     * 如果url是http链接，直接返回链接
     * 如果是本地组件：file://链接，则返回 url+entry,e.g. file://C:\users\neo\desktop\index.html#
     */
    getIndexUrl(hash) {
        return UrlUtils.getWidgetPackageIndexUrl(this.url, this.entry, hash == null ? this.hash : hash);
    }
}
