import { WidgetData } from "../model/WidgetData";
export interface SaveWidgetOption {
    sendBroadcast?: boolean;
    id?: string;
}
export interface IWidgetDataApi {
    findByName<T extends WidgetData>(name: string, type: {
        new (name: string, id?: string): T;
    }): Promise<T | undefined>;
    findByName<T extends WidgetData>(data: T): Promise<T | undefined>;
    save(data: WidgetData): Promise<string>;
    getStore(name: string): LocalForage;
    saveByName<T extends WidgetData>(data: T, options?: SaveWidgetOption): Promise<string>;
    find<T extends WidgetData>(name: string, id: string, type: {
        new (name: string, id?: string): T;
    }): Promise<T | undefined>;
}
type WidgetDataApiMethods = keyof IWidgetDataApi;
export declare class WidgetDataApiImpl implements IWidgetDataApi {
    private stores;
    /**
     * 保存组件数据
     * @param data
     */
    save(data: WidgetData): Promise<string>;
    /**
     * 获取组件 LocalForage 存储实例
     * @param name
     */
    getStore(name: string): LocalForage;
    /**
     * 通过组件名保存组件信息，通常用于存储可以在同类组件中共用的数据
     * @param data
     * @param options
     */
    saveByName<T extends WidgetData>(data: T, options?: SaveWidgetOption): Promise<string>;
    findByName<T extends WidgetData>(...args: any[]): Promise<T | undefined>;
    find<T extends WidgetData>(name: string, id: string, type: {
        new (name: string, id?: string): T;
    }): Promise<T | undefined>;
    private getKey;
}
declare const WidgetDataApi: IWidgetDataApi;
export { WidgetDataApi, WidgetDataApiMethods };
