import { Widget } from "./Widget";
import { LanguageCode, LanguageTextMap } from "../lang/LanguageCode";
type WidgetPackageOptions = {
    name: string;
    version: string;
    author: string;
    homepage: string;
    title: LanguageTextMap;
    description: LanguageTextMap;
    entry: string;
    remoteEntry?: string;
    remotePackage?: string;
    hash: boolean;
    url: string;
    lang?: LanguageCode;
    widgets?: Widget[];
    devOptions?: DevOptions;
};
export declare class WidgetPackage {
    /**
     * 组件包名,一般为域名倒置，e.g. com.example
     */
    readonly name: string;
    /**
     * 组件包版本，e.g. 1.0.2
     */
    readonly version: string;
    /**
     * 组件作者署名
     */
    readonly author: string;
    /**
     * 组件首页
     */
    readonly homepage?: string;
    /**
     * 组件描述
     */
    readonly title: {
        [key: LanguageCode | string]: string;
    };
    /**
     * 组件描述
     */
    readonly description: {
        [key: LanguageCode | string]: string;
    };
    /**
     * 组件入口文件，通常为 index.html
     */
    readonly entry: string;
    /**
     * 组件包的远程入口地址，
     */
    readonly remoteEntry?: string;
    readonly remotePackage?: string;
    /**
     * Hash路由模式，默认为true
     */
    readonly hash: boolean;
    /**
     * 可能是网络地址，或者本地路径（解压后的文件夹路径）,
     * 网络地址：https://www.bilibili.com
     * 本地地址：file:///C:/Users/neo/Desktop
     * 在测试时。地址通常为: http://127.0.0.1:8080
     */
    readonly url: string;
    readonly widgets: Widget[];
    readonly devOptions?: DevOptions;
    constructor(options: WidgetPackageOptions);
    static parseJSON(json: string): WidgetPackage;
    static parseObject(obj: any): WidgetPackage;
    /**
     * 获取组件包标题
     * @param lang 语言环境，不传则获取默认语言
     */
    getTitle(lang?: LanguageCode): string | undefined;
    /**
     * 获取组件包描述
     * @param lang 语言环境，不传则获取默认标题
     */
    getDescription(lang?: LanguageCode): string | undefined;
    /**
     * 获取组件完整路径
     * 如果url是http链接，直接返回链接
     * 如果是本地组件：file://链接，则返回 url+entry,e.g. file://C:\users\neo\desktop\index.html#
     */
    getIndexUrl(hash?: boolean): string;
}
export type DevOptions = {
    folder?: string;
    route?: boolean;
    devUrl?: string;
};
export {};
